@@ -39,6 +39,8 @@ class MetOfficeDataHub(BaseMetOfficeDataHub):
     def download_all_files(self, order_ids: Optional[List[str]] = None):
         """Download all files in the latest"""
 
+        logger.info("Downloading all files")
+
         if order_ids is None:
             all_orders = self.get_orders()
             order_ids = [order.orderId for order in all_orders.orders]
@@ -73,7 +75,7 @@ class MetOfficeDataHub(BaseMetOfficeDataHub):
                     file.local_filename = filename
                     self.files.append(file)
 
-        logger.info('All files downloaded')
+        logger.info("All files downloaded")
 
     def load_file(self, file) -> xr.Dataset:
         """Load one grib file"""
@@ -93,7 +95,7 @@ class MetOfficeDataHub(BaseMetOfficeDataHub):
         all_datasets_per_filename = {}
         for i, file in enumerate(self.files):
 
-            logger.debug(f'Loading file {i} out of {len(self.files)}')
+            logger.debug(f"Loading file {i} out of {len(self.files)}")
 
             variable = file.fileId
             variable = variable.split("_")[1]
